@@ -1,5 +1,5 @@
 
-#include <glib.h>
+#include <glibmm.h>
 
 // Disable the 'const' function attribute of the get_type() functions.
 // GCC would optimize them out because we don't use the return value.
@@ -37,14 +37,15 @@
 #include "holder.h"
 #include "metastore.h"
 #include "metastruct.h"
+#include "numeric.h"
 #include "quarklist.h"
 #include "row.h"
 #include "serveroperation.h"
 #include "serverprovider.h"
 #include "set.h"
+#include "sqlbuilder.h"
 #include "sqlexpr.h"
 #include "sqlparser.h"
-#include "sqlbuilder.h"
 #include "sqlstatement.h"
 #include "statement.h"
 #include "transactionstatus.h"
@@ -143,18 +144,18 @@ namespace Gnome { namespace Gda {
 void wrap_init()
 {
   // Register Error domains:
-  Glib::Error::register_domain(gda_config_error_quark(), &Gnome::Gda::ConfigError::throw_func);
-  Glib::Error::register_domain(gda_connection_error_quark(), &Gnome::Gda::ConnectionError::throw_func);
-  Glib::Error::register_domain(gda_data_model_error_quark(), &Gnome::Gda::DataModelError::throw_func);
-  Glib::Error::register_domain(gda_data_model_iter_error_quark(), &Gnome::Gda::DataModelIterError::throw_func);
-  Glib::Error::register_domain(gda_holder_error_quark(), &Gnome::Gda::HolderError::throw_func);
-  Glib::Error::register_domain(gda_meta_store_error_quark(), &Gnome::Gda::MetaStoreError::throw_func);
-  Glib::Error::register_domain(gda_meta_struct_error_quark(), &Gnome::Gda::MetaStructError::throw_func);
-  Glib::Error::register_domain(gda_server_provider_error_quark(), &Gnome::Gda::ServerProviderError::throw_func);
-  Glib::Error::register_domain(gda_sql_builder_error_quark(), &Gnome::Gda::SqlBuilderError::throw_func);
-  Glib::Error::register_domain(gda_sql_error_quark(), &Gnome::Gda::SqlError::throw_func);
-  Glib::Error::register_domain(gda_sql_parser_error_quark(), &Gnome::Gda::SqlParserError::throw_func);
-  Glib::Error::register_domain(gda_statement_error_quark(), &Gnome::Gda::StatementError::throw_func);
+  Glib::Error::register_domain(gda_config_error_quark(), &::Gnome::Gda::ConfigError::throw_func);
+  Glib::Error::register_domain(gda_connection_error_quark(), &::Gnome::Gda::ConnectionError::throw_func);
+  Glib::Error::register_domain(gda_data_model_error_quark(), &::Gnome::Gda::DataModelError::throw_func);
+  Glib::Error::register_domain(gda_data_model_iter_error_quark(), &::Gnome::Gda::DataModelIterError::throw_func);
+  Glib::Error::register_domain(gda_holder_error_quark(), &::Gnome::Gda::HolderError::throw_func);
+  Glib::Error::register_domain(gda_meta_store_error_quark(), &::Gnome::Gda::MetaStoreError::throw_func);
+  Glib::Error::register_domain(gda_meta_struct_error_quark(), &::Gnome::Gda::MetaStructError::throw_func);
+  Glib::Error::register_domain(gda_server_provider_error_quark(), &::Gnome::Gda::ServerProviderError::throw_func);
+  Glib::Error::register_domain(gda_sql_builder_error_quark(), &::Gnome::Gda::SqlBuilderError::throw_func);
+  Glib::Error::register_domain(gda_sql_error_quark(), &::Gnome::Gda::SqlError::throw_func);
+  Glib::Error::register_domain(gda_sql_parser_error_quark(), &::Gnome::Gda::SqlParserError::throw_func);
+  Glib::Error::register_domain(gda_statement_error_quark(), &::Gnome::Gda::StatementError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(gda_batch_get_type(), &Gnome::Gda::Batch_Class::wrap_new);
